@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -357,7 +357,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     def translate_text(
         self,
-        request: translation_service.TranslateTextRequest = None,
+        request: Union[translation_service.TranslateTextRequest, dict] = None,
         *,
         parent: str = None,
         target_language_code: str = None,
@@ -372,7 +372,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Translates input text and returns translated text.
 
         Args:
-            request (google.cloud.translate_v3.types.TranslateTextRequest):
+            request (Union[google.cloud.translate_v3.types.TranslateTextRequest, dict]):
                 The request object. The request message for synchronous
                 translation.
             parent (str):
@@ -527,7 +527,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     def detect_language(
         self,
-        request: translation_service.DetectLanguageRequest = None,
+        request: Union[translation_service.DetectLanguageRequest, dict] = None,
         *,
         parent: str = None,
         model: str = None,
@@ -540,7 +540,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Detects the language of text within a request.
 
         Args:
-            request (google.cloud.translate_v3.types.DetectLanguageRequest):
+            request (Union[google.cloud.translate_v3.types.DetectLanguageRequest, dict]):
                 The request object. The request message for language
                 detection.
             parent (str):
@@ -650,7 +650,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     def get_supported_languages(
         self,
-        request: translation_service.GetSupportedLanguagesRequest = None,
+        request: Union[translation_service.GetSupportedLanguagesRequest, dict] = None,
         *,
         parent: str = None,
         model: str = None,
@@ -663,7 +663,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         translation.
 
         Args:
-            request (google.cloud.translate_v3.types.GetSupportedLanguagesRequest):
+            request (Union[google.cloud.translate_v3.types.GetSupportedLanguagesRequest, dict]):
                 The request object. The request message for discovering
                 supported languages.
             parent (str):
@@ -769,7 +769,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     def translate_document(
         self,
-        request: translation_service.TranslateDocumentRequest = None,
+        request: Union[translation_service.TranslateDocumentRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -778,7 +778,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         r"""Translates documents in synchronous mode.
 
         Args:
-            request (google.cloud.translate_v3.types.TranslateDocumentRequest):
+            request (Union[google.cloud.translate_v3.types.TranslateDocumentRequest, dict]):
                 The request object. A document translation request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -818,7 +818,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     def batch_translate_text(
         self,
-        request: translation_service.BatchTranslateTextRequest = None,
+        request: Union[translation_service.BatchTranslateTextRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -835,7 +835,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         of the call.
 
         Args:
-            request (google.cloud.translate_v3.types.BatchTranslateTextRequest):
+            request (Union[google.cloud.translate_v3.types.BatchTranslateTextRequest, dict]):
                 The request object. The batch translation request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -887,7 +887,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     def batch_translate_document(
         self,
-        request: translation_service.BatchTranslateDocumentRequest = None,
+        request: Union[translation_service.BatchTranslateDocumentRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -904,7 +904,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         the call.
 
         Args:
-            request (google.cloud.translate_v3.types.BatchTranslateDocumentRequest):
+            request (Union[google.cloud.translate_v3.types.BatchTranslateDocumentRequest, dict]):
                 The request object. The BatchTranslateDocument request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -956,7 +956,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     def create_glossary(
         self,
-        request: translation_service.CreateGlossaryRequest = None,
+        request: Union[translation_service.CreateGlossaryRequest, dict] = None,
         *,
         parent: str = None,
         glossary: translation_service.Glossary = None,
@@ -968,7 +968,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         Returns NOT_FOUND, if the project doesn't exist.
 
         Args:
-            request (google.cloud.translate_v3.types.CreateGlossaryRequest):
+            request (Union[google.cloud.translate_v3.types.CreateGlossaryRequest, dict]):
                 The request object. Request message for CreateGlossary.
             parent (str):
                 Required. The project name.
@@ -1044,7 +1044,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     def list_glossaries(
         self,
-        request: translation_service.ListGlossariesRequest = None,
+        request: Union[translation_service.ListGlossariesRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1055,7 +1055,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         doesn't exist.
 
         Args:
-            request (google.cloud.translate_v3.types.ListGlossariesRequest):
+            request (Union[google.cloud.translate_v3.types.ListGlossariesRequest, dict]):
                 The request object. Request message for ListGlossaries.
             parent (str):
                 Required. The name of the project
@@ -1124,7 +1124,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     def get_glossary(
         self,
-        request: translation_service.GetGlossaryRequest = None,
+        request: Union[translation_service.GetGlossaryRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1135,7 +1135,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         exist.
 
         Args:
-            request (google.cloud.translate_v3.types.GetGlossaryRequest):
+            request (Union[google.cloud.translate_v3.types.GetGlossaryRequest, dict]):
                 The request object. Request message for GetGlossary.
             name (str):
                 Required. The name of the glossary to
@@ -1195,7 +1195,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
 
     def delete_glossary(
         self,
-        request: translation_service.DeleteGlossaryRequest = None,
+        request: Union[translation_service.DeleteGlossaryRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1207,7 +1207,7 @@ class TranslationServiceClient(metaclass=TranslationServiceClientMeta):
         doesn't exist.
 
         Args:
-            request (google.cloud.translate_v3.types.DeleteGlossaryRequest):
+            request (Union[google.cloud.translate_v3.types.DeleteGlossaryRequest, dict]):
                 The request object. Request message for DeleteGlossary.
             name (str):
                 Required. The name of the glossary to
